package com.ynet.life.security.key;

import com.ynet.life.security.key.KeysStoreParams;
import java.io.FileInputStream;
import java.io.IOException;
import java.security.KeyManagementException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;
import java.util.Enumeration;

public class KeysStore {

   private static KeyStore keyStore;
   private static KeysStoreParams storeParams;


   public static void init(KeysStoreParams params) throws NoSuchAlgorithmException, IOException, CertificateException, KeyStoreException, UnrecoverableKeyException, KeyManagementException {
      storeParams = params;
   }

   public static PublicKey getPublicKey(String alias) throws KeyStoreException, IOException, NoSuchAlgorithmException, CertificateException {
      getKeyStore();
      return keyStore.getCertificate(alias).getPublicKey();
   }

   public static PrivateKey getPrivateKey(String alias) throws KeyStoreException, IOException, NoSuchAlgorithmException, CertificateException, UnrecoverableKeyException {
      getKeyStore();
      return (PrivateKey)keyStore.getKey(alias, storeParams.getKeyStorePass());
   }

   private static KeyStore getKeyStore() throws KeyStoreException, IOException, NoSuchAlgorithmException, CertificateException {
      if(keyStore != null) {
         return keyStore;
      } else {
         FileInputStream in = null;

         KeyStore ioe1;
         try {
            String ioe = storeParams.getKeyStoreFile();
            keyStore = KeyStore.getInstance(storeParams.getKeyStoreType());
            in = new FileInputStream(ioe);
            keyStore.load(in, storeParams.getKeyStorePass());
            ioe1 = keyStore;
         } catch (IOException var4) {
            keyStore = null;
            throw var4;
         } finally {
            in.close();
         }

         return ioe1;
      }
   }

   public static void main(String[] e) {
      try {
         init(new KeysStoreParams("E:/Life.jks", "123456"));
         Enumeration e1 = getKeyStore().aliases();

         while(e1.hasMoreElements()) {
            String als = (String)e1.nextElement();
            System.out.println("alias: ".concat(String.valueOf(als)));
         }

         System.out.println("\nmypairkey public key:\n" + getPublicKey("mypairkey"));
         System.out.println("mypairkey private key:\n" + getPrivateKey("mypairkey"));
      } catch (Exception var2) {
         var2.printStackTrace();
      }
   }
}
